@@ -19,11 +19,14 @@ PRECOMMITDIR=precommit/src/main/shell
 
 "${PRECOMMITDIR}/test-patch.sh" \
   --plugins=all \
+  --bugcomments=briefreport,csvout,htmlout,junit \
   --mvn-custom-repos \
   --mvn-custom-repos-dir=/tmp/yetus-m2 \
   --patch-dir=/tmp/yetus-out \
   --tests-filter=checkstyle,test4tests \
+  --csv-report-file=/tmp/yetus-out/report.csv \
   --junit-report-xml=/tmp/yetus-out/junit-results.xml \
+  --junit-report-style=full \
   --docker \
   --dockerfile="${PRECOMMITDIR}/test-patch-docker/Dockerfile" \
-  --docker-cache-from=ghcr.io/apache/yetus-base:main,ubuntu:focal
+  --docker-cache-from=ghcr.io/apache/yetus-base:main,ubuntu:jammy
